@@ -56,8 +56,7 @@ Copyright_License {
 #include "IO/Async/GlobalIOThread.hpp"
 #include "Thread/Debug.hpp"
 
-#ifdef IOIOLIB
-#include "Android/IOIOHelper.hpp"
+#include "IOIOHelper.hpp"
 #include "NativeBMP085Listener.hpp"
 #include "BMP085Device.hpp"
 #include "NativeI2CbaroListener.hpp"
@@ -66,7 +65,6 @@ Copyright_License {
 #include "NunchuckDevice.hpp"
 #include "NativeVoltageListener.hpp"
 #include "VoltageDevice.hpp"
-#endif
 
 #ifndef NDEBUG
 #include "Screen/OpenGL/Texture.hpp"
@@ -84,9 +82,7 @@ EventQueue *event_queue;
 Vibrator *vibrator;
 bool os_haptic_feedback_enabled;
 
-#ifdef IOIOLIB
 IOIOHelper *ioio_helper;
-#endif
 
 extern "C" {
   /* workaround for
@@ -118,7 +114,6 @@ Java_org_xcsoar_NativeView_initializeNative(JNIEnv *env, jobject obj,
   NativeInputListener::Initialise(env);
   PortBridge::Initialise(env);
   BluetoothHelper::Initialise(env);
-#ifdef IOIOLIB
   IOIOHelper::Initialise(env);
   NativeBMP085Listener::Initialise(env);
   BMP085Device::Initialise(env);
@@ -128,7 +123,6 @@ Java_org_xcsoar_NativeView_initializeNative(JNIEnv *env, jobject obj,
   NunchuckDevice::Initialise(env);
   NativeVoltageListener::Initialise(env);
   VoltageDevice::Initialise(env);
-#endif
 
   context = new Context(env, _context);
 
@@ -149,15 +143,20 @@ Java_org_xcsoar_NativeView_initializeNative(JNIEnv *env, jobject obj,
   Vibrator::Initialise(env);
   vibrator = Vibrator::Create(env, *context);
 
-#ifdef IOIOLIB
   ioio_helper = new IOIOHelper(env);
-#endif
 
   ScreenInitialized();
   AllowLanguage();
   return Startup();
 }
 
+void
+OnLogCatFinished(bool crash_found)
+{
+  if (crash_found)
+    CommonInterface::main_window->SendCrash();
+}
+
 gcc_visibility_default
 JNIEXPORT void JNICALL
 Java_org_xcsoar_NativeView_runNative(JNIEnv *env, jobject obj)
@@ -166,14 +165,7 @@ Java_org_xcsoar_NativeView_runNative(JNIEnv *env, jobject obj)
 
   OpenGL::Initialise();
 
-  if (CheckLogCat())
-    ShowMessageBox(_T("How embarassing, we're terribly sorry!\n"
-                      "Please submit a bug report and "
-                      "include the file from the 'crash' directory.\n"
-                      "http://bugs.xcsoar.org/newticket\n"
-                      "After your report, we'll fix it ASAP."),
-                   _T("XCSoar has crashed recently"),
-                   MB_OK|MB_ICONERROR);
+  CheckLogCat(*io_thread);
 
   CommonInterface::main_window->RunEventLoop();
 }
@@ -182,6 +174,8 @@ gcc_visibility_default
 JNIEXPORT void JNICALL
 Java_org_xcsoar_NativeView_deinitializeNative(JNIEnv *env, jobject obj)
 {
+  StopLogCat();
+
   InitThreadDebug();
 
   delete CommonInterface::main_window;
@@ -189,10 +183,8 @@ Java_org_xcsoar_NativeView_deinitializeNative(JNIEnv *env, jobject obj)
   DisallowLanguage();
   Fonts::Deinitialize();
 
-#ifdef IOIOLIB
   delete ioio_helper;
   ioio_helper = NULL;
-#endif
 
   delete vibrator;
   vibrator = NULL;
@@ -209,7 +201,6 @@ Java_org_xcsoar_NativeView_deinitializeNative(JNIEnv *env, jobject obj)
 
   delete context;
 
-#ifdef IOIOLIB
   BMP085Device::Deinitialise(env);
   NativeBMP085Listener::Deinitialise(env);
   I2CbaroDevice::Deinitialise(env);
@@ -219,7 +210,6 @@ Java_org_xcsoar_NativeView_deinitializeNative(JNIEnv *env, jobject obj)
   VoltageDevice::Deinitialise(env);
   NativeVoltageListener::Deinitialise(env);
   IOIOHelper::Deinitialise(env);
-#endif
   BluetoothHelper::Deinitialise(env);
   NativeInputListener::Deinitialise(env);
   InternalSensors::Deinitialise(env);
