@@ -47,10 +47,8 @@
 #ifdef ANDROID
 #include "Java/Global.hpp"
 #include "Android/BluetoothHelper.hpp"
-#ifdef IOIOLIB
 #include "Device/Port/AndroidIOIOUartPort.hpp"
 #endif
-#endif
 
 enum ControlIndex {
   Port, BaudRate, BulkBaudRate, TCPPort, I2CBus, I2CAddr, PressureUsage, Driver,
@@ -264,7 +262,7 @@ FillAndroidBluetoothPorts(DataFieldEnum &df, const DeviceConfig &config)
 static void
 FillAndroidIOIOPorts(DataFieldEnum &df, const DeviceConfig &config)
 {
-#if defined(ANDROID) && defined(IOIOLIB)
+#if defined(ANDROID)
   df.EnableItemHelp(true);
 
   TCHAR tempID[4];
