@@ -28,6 +28,11 @@ Copyright_License {
 #include "Util/Macros.hpp"
 #include "Interface.hpp"
 
+#ifdef ANDROID
+#include "Android/BluetoothHelper.hpp"
+#include "Java/Global.hpp"
+#endif
+
 #include <stdio.h>
 
 static const char *const port_type_strings[] = {
@@ -133,6 +138,21 @@ DeviceConfig::ShouldReopenOnTimeout() const
   gcc_unreachable();
 }
 
+bool
+DeviceConfig::BluetoothNameStartsWith(const char *prefix) const
+{
+#ifdef ANDROID
+  if (port_type != PortType::RFCOMM)
+    return false;
+
+  const char *name =
+    BluetoothHelper::GetNameFromAddress(Java::GetEnv(), bluetooth_mac.c_str());
+  return name != nullptr && StringStartsWith(name, prefix);
+#else
+  return false;
+#endif
+}
+
 const TCHAR *
 DeviceConfig::GetPortName(TCHAR *buffer, size_t max_size) const
 {
@@ -143,10 +163,18 @@ DeviceConfig::GetPortName(TCHAR *buffer, size_t max_size) const
   case PortType::SERIAL:
     return path.c_str();
 
-  case PortType::RFCOMM:
-    StringFormat(buffer, max_size, _T("Bluetooth %s"),
-                 bluetooth_mac.c_str());
+  case PortType::RFCOMM: {
+    const TCHAR *name = bluetooth_mac.c_str();
+#ifdef ANDROID
+    const char *name2 =
+      BluetoothHelper::GetNameFromAddress(Java::GetEnv(), name);
+    if (name2 != nullptr)
+      name = name2;
+#endif
+
+    StringFormat(buffer, max_size, _T("Bluetooth %s"), name);
     return buffer;
+    }
 
   case PortType::RFCOMM_SERVER:
     return _("Bluetooth server");
